use crate::cell::CellView;
use crate::transducer::Stateful;

pub trait Poll<T: Copy> {
    async fn poll() -> T;
}

pub struct StatefulInput<'a, T: Copy> {
    pub state_cell: CellView<'a, T>,
}

impl<'a, T: Copy> Stateful for StatefulInput<'a, T> {
    type Value = T;

    #[inline(always)]
    fn state_cell(&self) -> CellView<'a, Self::Value> {
        self.state_cell
    }

    #[inline]
    fn state(&self) -> Self::Value {
        self.state_cell.get()
    }
}
